<?php

	namespace Apifon;

	require(__DIR__ . "/Response/ErrorResponse.php");
	require(__DIR__ . "/OAuthRegistry.php");
	require(__DIR__ . "/Security/Hmac.php");

	use Apifon\Resource\AbstractResource;
	use Apifon\Response\ErrorResponse;
	use Apifon\Security\Hmac;

	class Mookee
	{

		public static $active_oauth_identifier = NULL;
		public static $auto_refresh_tokens = False;
		public static $active_identifier = null;
		public static $production_IdentityServerUrl = "https://ids.apifon.com/";
		public static $staging_IdentityServerUrl = "https://ids-staging.apifon.com/";
		private static $production_url = "https://ars.apifon.com";
		private static $staging_url = "https://ars-staging.apifon.com";
		private static $base_url;
		private static $credentials = array();
		private static $staging = false;
		private static $instance = null;
		private static $key = "";

		public function __construct()
		{
		}

		public static function getInstance()
		{
			// Check if instance already exists
			if (self::$instance == null) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		public static function setIdentityServerUrl()
		{
			if (self::$staging) {

				self::$staging_IdentityServerUrl;
				return self::$staging_IdentityServerUrl;

			} else {
				self::$production_IdentityServerUrl;
				return self::$production_IdentityServerUrl;
			}

		}

		public static function setStaging($enable)
		{
			self::$staging = $enable;
		}

		public static function getActive_oauth_identifier()
		{
			return self::$active_oauth_identifier;
		}

		public static function remove_OAuth_resource($identifier)
		{

			\Apifon\OAuthRegistry::getInstance()->remove_OAuth_resource($identifier);
		}

		public static function add_OAuth_resource_and_get_token($identifier, $oauth_configuration)
		{

			\Apifon\OAuthRegistry::getInstance()->add_OAuth_resource_and_get_token($identifier, $oauth_configuration);
		}

		public static function dispatch(AbstractResource $resource)
		{

			if (self::$staging) {
				self::$base_url = self::$staging_url;
			} else {
				self::$base_url = self::$production_url;
			}

			$endpoint = $resource->getCurEndpoint();;
			$body = $resource->getCurBody();
			$method = $resource->getCurMethod();
			$clearEndpoint = $resource->getClearEndpoint();

			try {
				return self::makeCall($endpoint, $method, $body, $clearEndpoint);


			} catch (\Exception $e) {
				throw $e;
			}
		}

		private static function makeCall($endpoint, $method, $body, $clearEndpoint)
		{
			if (isset($clearEndpoint)) {
				$endpointForHash = $clearEndpoint;
			} else {
				$endpointForHash = $endpoint;
			}
			$url = self::$base_url . $endpoint;
			//Get the date from internal function
			$requestDate = self::getRequestDate();
			//Build the message
			$message = $method . "\n"
				. $endpointForHash . "\n"
				. $body . "\n"
				. $requestDate;

			if (self::$active_oauth_identifier !== NULL) {
				$header = array();
				$header[] = "Content-type: application/json";
				$header[] = "Authorization:  Bearer" . "  " . \Apifon\OAuthRegistry::getInstance()->get_active_token(self::$active_identifier);

				//Make the curl call
				$curl = curl_init($url);
				curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($curl, CURLOPT_HEADER, false);
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
				curl_setopt($curl, CURLOPT_CUSTOMREQUEST, $method);
				curl_setopt($curl, CURLOPT_POSTFIELDS, $body);

				$response = curl_exec($curl);
				$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
				curl_close($curl);
				if ($status != 200 && $status != 201 && $status != 204 && !(is_int(strpos($url, "/verify/")) && $status === 403) && !(is_int(strpos($url, "otp/create")) && $status === 403)) {
					if ($response) {
						$errorResponse = new ErrorResponse(json_decode($response, true));
						throw new \Exception("Error: call to URL $url failed with response" . " " . json_encode($errorResponse));
					} else {
						throw new \Exception("Error: call to URL $url failed with status $status, response $response");
					}
				}

				return $response;
			} else {
				//Get the signature from the hmac class
				$signature = Hmac::sign($message, self::$credentials[self::$key]["secret"]);
				//Build the authorization header
				$header = array();
				$header[] = "Content-type: application/json";
				$header[] = "Authorization: ApifonWS " . self::$credentials[self::$key]["token"] . ":" . $signature;
				$header[] = "X-ApifonWS-Date: " . $requestDate;
				//Make the curl call
				$curl = curl_init($url);
				curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($curl, CURLOPT_HEADER, false);
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
				curl_setopt($curl, CURLOPT_CUSTOMREQUEST, $method);
				curl_setopt($curl, CURLOPT_POSTFIELDS, $body);

				$response = curl_exec($curl);
				$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
				curl_close($curl);
				if ($status != 200 && $status != 201 && $status != 204 && !(is_int(strpos($url, "/verify/")) && $status === 403) && !(is_int(strpos($url, "otp/create")) && $status === 403)) {
					if ($response) {
						$errorResponse = new ErrorResponse(json_decode($response, true));
						throw new \Exception("Error: call to URL $url failed with response" . " " . json_encode($errorResponse));
					} else {
						throw new \Exception("Error: call to URL $url failed with status $status, response $response");
					}
				}

				return $response;
			}

		}

		private static function getRequestDate()
		{
			$dateTime = new \DateTime();
			$dateTime->setTimezone(new \DateTimeZone('GMT'));
			return $dateTime->format('D, d M Y H:i:s T');
		}

		public static function addCredentials($key, $token, $privateKey)
		{
			self::$credentials[$key] = ["token" => $token, "secret" => $privateKey];
		}

		public static function setActiveCredential($key)
		{
			self::$key = $key;
		}

		public function getActive_oauth_token_to_make_an_API_call($identifier)
		{
			self::$active_identifier = $identifier;

		}

		public function getCurlMethod($method)
		{

		}

		public function set_mookee_to_oauth_mode($identifier, $auto_refresh_tokens)
		{
			self::setActive_oauth_identifier($identifier);
			self::setAuto_refresh_tokens($auto_refresh_tokens);

			return;
		}

		public function setActive_oauth_identifier($identifier)
		{
			self::$active_oauth_identifier = $identifier;
		}

		//private set date with timezone
		public static function setAuto_refresh_tokens($auto_refresh_tokens)
		{
			return self::$auto_refresh_tokens = $auto_refresh_tokens;
		}
	}

