<?php

	namespace Apifon\Resource {

		require_once(__DIR__ . "/AbstractResource.php");
		require_once("Apifon/Response/OAuthResponseError.php");

		use Apifon\Mookee;

		class OAuthResource extends AbstractResource
		{
			var $AUTHORIZE_URL = "oauth2/authorize";
			var $TOKEN_URL = "oauth2/token";
			var $REVOKE_URL = "oauth2/revoke";

			protected $oauth_configuration_CliendId;
			protected $oauth_configuration_CliendSecret;

			function __construct($oauth_configuration)
			{
				$this->oauth_configuration_CliendId = $oauth_configuration->getClientId();
				$this->oauth_configuration_CliendSecret = $oauth_configuration->getClientSecret();
				parent::__construct(Mookee::setIdentityServerUrl());
			}

			public function getTokensForClientCredentialsGrant()
			{
				$header = array();
				$header[] = "Content-type: application/x-www-form-urlencoded";
				$curl = curl_init();
				curl_setopt($curl, CURLOPT_URL, $this->getEndpoint() . $this->TOKEN_URL . '?grant_type=' . 'client_credentials' .
					'&client_id=' . $this->oauth_configuration_CliendId . '&client_secret=' . $this->oauth_configuration_CliendSecret . '&scope=');
				curl_setopt($curl, CURLOPT_POST, true);
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($curl, CURLOPT_HEADER, false);

				$response = curl_exec($curl);
				$result = json_decode($response, true);

				$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
				if ($status !== 200) {
					$OAuthResponseError = new \Apifon\Response\OAuthResponseError();
					$error = $OAuthResponseError->getError();
					$status = $OAuthResponseError->getStatus();
					$error_desc = $OAuthResponseError->getError_description();
					echo $error, $status, $error_desc;
					echo('Failed to retrieve token');

				}
				curl_close($curl);

				return $result;
			}


			public function revokeToken($token)
			{
				$header = array();
				$header[] = "Content-type: application/x-www-form-urlencoded";
				$curl = curl_init();

				curl_setopt($curl, CURLOPT_URL, $this->getEndpoint() . $this->REVOKE_URL .
					'?client_id=' . $this->oauth_configuration_CliendId . '&client_secret=' . $this->oauth_configuration_CliendSecret . '&token=' . $token);
				curl_setopt($curl, CURLOPT_POST, true);
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($curl, CURLOPT_HEADER, false);

				$response = curl_exec($curl);

				$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
				if ($status !== 200) {
					$OAuthResponseError = new \Apifon\Response\OAuthResponseError();
					$error = $OAuthResponseError->getError();
					$status = $OAuthResponseError->getStatus();
					$error_desc = $OAuthResponseError->getError_description();
					echo $error, $status, $error_desc;
					echo('Failed to retrieve token');
				}
				curl_close($curl);

				return $status;
			}
		}
	}
