<?php

namespace Apifon\Resource;

require_once("./Apifon/Response/SubscriberResponse.php");
require_once("./Apifon/Response/SubscriberResponseMulty.php");
require_once("./Apifon/Response/SubscribersQueryResponse.php");
require_once("./Apifon/Model/request/SubscriberUpdateRemoveRequest.php");

use Apifon\Resource\AbstractResource;
use Apifon\Model\request\SubscriberRequest;
use Apifon\Model\request\QuerySubscribersBodyRequest;
use Apifon\Model\request\SubscriberUpdateRemoveRequest;
use Apifon\Response\SubscriberResponse;
use Apifon\Response\SubscriberResponseMulty;
use Apifon\Response\SubscribersQueryResponse;
use Exception;

class SubscriberResource extends AbstractResource
{
    public function __construct()
    {
        parent::__construct($endpoint = "/services/api/v1/list/{list_id}/subscriber");
    }

    public function replacePlaceholderAndSetUrl($endPoint, $listId)
    {
        $this->setClearEndPoint(str_replace( "{list_id}", $listId, $endPoint));
        $this->setCurEndpoint(str_replace( "{list_id}", $listId, $endPoint));
    }

    public function addSubscriber($request)
    {
        if ($request->getListId() == null) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        $this->setCurMethod('POST');
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());

        if(is_string($request)){
            $this->setCurBody($request);
        }
        elseif($request instanceof SubscriberRequest){
            $this->setCurBody($request->getBody());
        }
        $return = json_decode(parent::dispatch(), true);
        return $return;
    }

    public function updateSubscriber($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        if (!$request->getLookupMd5()) {
            throw new Exception("LookupMd5 is missing. please set DestinationId or EmailId on request object with setLookupMd5.");
        }
        $this->setCurMethod("PUT");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->getLookupMd5());
        $this->setClearEndpoint($this->getCurEndpoint());
        if(is_string($request)){
            $this->setCurBody($request);
        }
        elseif($request instanceof SubscriberUpdateRemoveRequest){
            $this->setCurBody($request->getBody());
        }
        $return = json_decode(parent::dispatch(), true);
        return $return;

    }

    public function getSubscribers($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        $this->setCurMethod("GET");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->toQueryParamRequest());
        $return = json_decode(parent::dispatch(), true);
        $result = new SubscriberResponseMulty($return);
        return $result;
    }

    public function getSubscriber($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        if (!$request->getLookupMd5()) {
            throw new Exception("LookupMd5 is missing. please set DestinationId or EmailId on request object with setLookupMd5.");
        }
        $this->setCurMethod("GET");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->getLookupMd5().$request->SingleFieldQueryParams());
        $this->setClearEndpoint($this->getClearEndpoint().$request->getLookupMd5());
        $return = json_decode(parent::dispatch(), true);
        $result = new SubscriberResponse($return);
        return $result;
    }

    public function querySubscribers($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        if(is_string($request)){
            $this->setCurBody($request);
        }
        elseif($request instanceof QuerySubscribersBodyRequest){
            $this->setCurBody($request->getBody());
        }
        $this->setCurMethod("POST");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().'query');
        $this->setClearEndPoint($this->getCurEndpoint());
        $return = json_decode(parent::dispatch(), true);
        $results = new SubscribersQueryResponse($return);
        return $results;
    }

    public function subscribeSubscriber($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        $this->setCurMethod("POST");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->getLookupMd5().$request->SingleFieldQueryParams().'/subscribe');
        $this->setClearEndpoint($this->getClearEndpoint().$request->getLookupMd5().'/subscribe');
        $return = json_decode(parent::dispatch(), true);
        return $return;
    }

    public function unsubscribeSubscriber($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        $this->getCurMethod("POST");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint() . "/", $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->getLookupMd5().$request->SingleFieldQueryParams().'/unsubscribe');
        $this->setClearEndpoint($this->getClearEndpoint().$request->getLookupMd5().'/unsubscribe');
        $return = json_decode(parent::dispatch(), true);
        return $return;
    }

    public function removeSubscriber($request)
    {
        if (!$request->getListId()) {
            throw new Exception("List id is missing, please setListId on request object.");
        }
        $this->setCurMethod("DELETE");
        $this->replacePlaceholderAndSetUrl($this->getEndpoint().'/', $request->getListId());
        $this->setCurEndpoint($this->getCurEndpoint().$request->getLookupMd5());
        $this->setClearEndpoint($this->getCurEndpoint());
        $return = json_decode(parent::dispatch(), true);
        return $return;
    }
}