<?php

use Apifon\Mookee;
use Apifon\Resource\ListResource;
use Apifon\Model\request\ListRequest;
use Apifon\Model\request\ListQueryRequest;
use Apifon\Resource\SubscriberFieldResource;
use Apifon\Model\request\SubscriberFieldRequest;
use Apifon\Resource\GdprFieldResource;
use Apifon\Model\request\GdprFieldRequest;
use Apifon\Resource\SubscriberResource;
use Apifon\Model\request\SubscriberQueryRequest;
use Apifon\Model\request\QuerySubscribersBodyRequest;
use Apifon\Model\request\SubscriberUpdateRemoveRequest;
use Apifon\Model\request\SubscriberRequest;

require_once("../Apifon/Mookee.php");
require_once("../Apifon/Security/Hmac.php");
require_once("../Apifon/Resource/AbstractResource.php");
require_once("../Apifon/Resource/ListResource.php");
require_once("../Apifon/Model/request/ListRequest.php");
require_once("../Apifon/Model/request/ListQueryRequest.php");
require_once("../Apifon/Resource/SubscriberFieldResource.php");
require_once("../Apifon/Model/request/SubscriberFieldRequest.php");
require_once("../Apifon/Resource/GdprFieldResource.php");
require_once("../Apifon/Model/request/GdprFieldRequest.php");
require_once("../Apifon/Resource/SubscriberResource.php");
require_once("../Apifon/Model/request/SubscriberQueryRequest.php");
require_once("../Apifon/Model/request/QuerySubscribersBodyRequest.php");
require_once("../Apifon/Model/request/SubscriberUpdateRemoveRequest.php");
require_once("../Apifon/Model/request/SubscriberRequest.php");


$listResource = new ListResource();
$listQueryRequest = new ListQueryRequest();
$listRequest = new ListRequest();
$subscriberFieldResource = new SubscriberFieldResource();
$subscriberFieldRequest = new SubscriberFieldRequest();
$gdprFieldResource = new GdprFieldResource();
$gdprFieldRequest = new GdprFieldRequest();
$subscriberResource = new SubscriberResource();
$subscriberQueryRequest = new SubscriberQueryRequest();
$querySubscribersBodyRequest = new QuerySubscribersBodyRequest();
$subscriberUpdateRemoveRequest = new SubscriberUpdateRemoveRequest();
$subscriberRequest = new SubscriberRequest();

Mookee::addCredentials("sms","Your_SMS_Token", "Your_SMS_Secret_Key");
Mookee::setActiveCredential("sms");

//Get lists
function getLists($listResource, $listQueryRequest)
{
    $listQueryRequest->setType("ADVANCED");
    $listQueryRequest->setPage(1);
    $listQueryRequest->setSize(20);
    $listQueryRequest->setSort("dateCreated");
    $listQueryRequest->setSortDir("ASC");
    return $listResource->getLists($listQueryRequest);
}

//Get a specific list
function getList($listResource, $listQueryRequest, $lists)
{
    $list = $lists->getResults()[0];
    //Clear listQueryRequest object
    $listQueryRequest->clearObj();
    $listQueryRequest->setListId($list->getId());
    //Get only campaign_defaults of a specific list
    $listQueryRequest->setFields('campaign_defaults');
    return $listResource->getList($listQueryRequest);
}

function addAList($listResource, $listRequest)
{
    $listRequest->setTitle("A NEW LIST");
    $listRequest->setType("ADVANCED");
    $listRequest->setDescription("CREATING NEW LIST");
    $listRequest->setPrefix('30');
    //You can create a campaignDefaults object for the listRequest
    $campaignDefaultsObject = $listRequest->campaignDefaultsBuilder();
    $campaignDefaultsObject->setFrom("email");
    $campaignDefaultsObject->setReplyTo("email");
    $campaignDefaultsObject->setSenderName("name");
    //Set this object to listRequest
    $listRequest->setCampaignDefaults($campaignDefaultsObject);
    //You can create a gdpr property object for the list Request
    $gdprPropertiesObject = $listRequest->gdprPropertiesBuilder();
    $gdprPropertiesObject->setGdprCompliant(true);
    $gdprPropertiesObject->setLegalText("By clicking below, you agree that we may process your information in accordance with your communication preferences. These can be modified at any time, by contacting us at  g.afentoulis@apifon.com. All the data given in this form will be treated with respect based on your preferences. For more information about our privacy practices, please visit our website.");
    $gdprPropertiesObject->setTitle("Marketing Permissions");
    $gdprPropertiesObject->setDescription("John we will use the given information with respect, to contact you according to your preferences. Please let us know about the communication activities you would like to hear from us:");
    //Set this object to listRequest
    $listRequest->setGdprProperties($gdprPropertiesObject);
    $listResource->addList($listRequest);
}
//Update List
function updateList($listResource, $listRequest, $list)
{
    //When some of the properties omit in request object of update they ll be removed from the list
    $listRequest->clearObj();
    $listRequest->setTitle("TITLE UPDATED");
    $listRequest->setPrefix("30");
    $listRequest->setListId($list->getId());
    $campaignDefaultsObject = $listRequest->campaignDefaultsBuilder();
    $campaignDefaultsObject->setFrom("email@email.com");
    $campaignDefaultsObject->setReplyTo("email@email.com");
    $campaignDefaultsObject->setSenderName("name is what");
    $campaignDefaultsObject->setSenderId('smsSenderId');
    $listRequest->setCampaignDefaults($campaignDefaultsObject);
    //You can create a gdpr property object for the list Request
    $gdprPropertiesObject = $listRequest->gdprPropertiesBuilder();
    $gdprPropertiesObject->setGdprCompliant(false);
    $gdprPropertiesObject->setLegalText("By clicking below, you agree that we may process your information in accordance with your communication preferences. These can be modified at any time, by contacting us at  g.afentoulis@apifon.com. All the data given in this form will be treated with respect based on your preferences. For more information about our privacy practices, please visit our website.");
    $gdprPropertiesObject->setTitle("Marketing Permissions");
    $gdprPropertiesObject->setDescription("John we will use the given information with respect, to contact you according to your preferences. Please let us know about the communication activities you would like to hear from us:");
    //Set this object to listRequest
    $listRequest->setGdprProperties($gdprPropertiesObject);
    $listResource->updateList($listRequest);

}
//Remove a list
function removeList($listResource, $listRequest, $list)
{
    $listRequest->clearObj();
    $listRequest->setListId($list->getId());
    $listResource->removeList($listRequest);
}
//Add a subscriber field to a specific list
function addSubscriberField($subscriberFieldResource, $subscriberFieldRequest, $list)
{
    $subscriberFieldRequest->setListId($list->getId());
    $subscriberFieldRequest->setLength('10');
    $subscriberFieldRequest->setType("DATE");
    //SET DATE FORMAT USED ONLY FOR FIELD OF TYPE DATE
    $subscriberFieldRequest->setDateFormat("yy-MM-dd");
    $subscriberFieldRequest->setName("BirthDay");
    $subscriberFieldResource->addSubscriberField($subscriberFieldRequest);
}

//Update a subscriber field from a specific list
function updateSubscriberField($subscriberFieldResource, $subscriberFieldRequest, $list)
{
    $subscriberFieldRequest->clearObj();
    $subscriberFieldRequest->setListId($list->getId());
    $subscriberFieldRequest->setLength('10');
    $subscriberFieldRequest->setField("date_BIRTHDAY");
    $subscriberFieldRequest->setDateFormat("yy-MM-dd");
    $subscriberFieldRequest->setName("Name day");
    $subscriberFieldResource->updateSubscriberField($subscriberFieldRequest);
}
//Remove a subscriber field from a specific list
function removeSubscriberField($subscriberFieldResource, $subscriberFieldRequest, $list)
{
    $subscriberFieldRequest->clearObj();
    $subscriberFieldRequest->setListId($list->getId());
    $subscriberFieldRequest->setField("date_BIRTHDAY");
    $subscriberFieldResource->removeSubscriberField($subscriberFieldRequest);
}

//Add GdprField to a specific list
function addGdprField($gdprFieldResource, $gdprFieldRequest, $list)
{
    $gdprFieldRequest->setListId($list->getId());
    $gdprFieldRequest->setName("GDPR FIELD TEST");
    $gdprFieldRequest->setDescription("GDPR FIELD FOR TEST");
    $gdprFieldResource->addGdprField($gdprFieldRequest);
}

//Update GdprField
function updateGdprField($gdprFieldResource, $gdprFieldRequest, $list)
{
    $gdprFieldRequest->setListId($list->getId());
    $gdprFieldRequest->setName("Collection");
    $gdprFieldRequest->setDescription("collect information for statistics and sales");
    //Use field identifier to update specific gdpr field
    $gdprFieldRequest->setField('COLLECT');
    $gdprFieldResource->updateGdprField($gdprFieldRequest);
}

//Get subscribers of a specific list
function getSubscribers($subscriberResource, $subscriberQueryRequest, $list)
{
    $subscriberQueryRequest->setListId($list->getId());
    //Only the subscribers that are subscriber for mobile
    $subscriberQueryRequest->setStatus("SUBSCRIBED");
    $subscriberQueryRequest->setPage(1);
    $subscriberQueryRequest->setSize(200);
    $subscriberQueryRequest->setSort("id");
    $subscriberQueryRequest->setSortDir("ASC");
    return $subscriberResource->getSubscribers($subscriberQueryRequest);
}

//Query subscribers of a specific list
function querySubscribers($subscriberResource, $querySubscriberBodyRequest,$list)
{
    $querySubscriberBodyRequest->setListId("5dc9343575526c04c84bb907");
    //Condition object initialization
    $conditions1 = $querySubscriberBodyRequest->conditionsBuilder();
    //Set the conditions for searching in the condition object
    //Use dot notation in setName if you want to search by subscriberField
    $conditions1->setName("subscriber_fields.FIRST_NAME");
    $conditions1->setOp("beginsWith");
    $conditions1->setVl("Jo");
    //If you want second condition create a new instance of conditions
    $conditions2 = $querySubscriberBodyRequest->conditionsBuilder();
    $conditions2->setName("subscriber_fields.GENDER");
    $conditions2->setOp("eq");
    $conditions2->setVl("Male");
    //Response will include values only for the fields inside setFields
    $querySubscriberBodyRequest->setFields("subscriber_fields", "destination_id", "destination", "id");
    //Set the conditions to querySubscriberBodyRequest
    $querySubscriberBodyRequest->setConditions($conditions1);
    $querySubscriberBodyRequest->setConditions($conditions2);
    //Set sorting object
    $sortingObj = $querySubscriberBodyRequest->sortingBuilder();
    $sortingObj->setSortDir("DESC");
    $sortingObj->setSortField("destination");
    $querySubscriberBodyRequest->setSort($sortingObj);
    return $subscriberResource->querySubscribers($querySubscriberBodyRequest);
}

//Add a subscriber to a specific field
function addSubscriber($subscriberResource, $subscriberRequest, $list)
{
    $subscriberRequest->setListId($list->getId());
    $subscriberRequest->setDestination("306973954742");
    $subscriberRequest->setStatus("SUBSCRIBED");
    //Add values to subscriber fields
    $subscriberRequest->setSubscriberFields(array("FIRST_NAME"=> "Jonathan", "GENDER" => "Male"));
    //Instantiate a gdprFieldConsent object
    $gdprFieldConsent = $subscriberRequest->gdprFieldConsentBuilder();
    //Set mobile or email consent
    $gdprFieldConsent->setMobile(true);
    //Create an associative array as property insert the name of gpdr field and as value the gdprFieldConsent object
    $subscriberRequest->setGdprFields(array("GDPR_FIELD_TEST" => $gdprFieldConsent));
    $subscriberResource->addSubscriber($subscriberRequest);
}

//update a subscriber from a specific list
function updateSubscriber($subscriberResource, $subscriberUpdateRemoveRequest, $list, $subscriber)
{
    $subscriberUpdateRemoveRequest->setListId($list->getId());
    $subscriberUpdateRemoveRequest->setDestination("306973954742");
    $subscriberUpdateRemoveRequest->setStatus("SUBSCRIBED");
    //Set for LookupMd5 the destinationId or emailId of the subscriber
    $subscriberUpdateRemoveRequest->setLookupMd5($subscriber->getDestinationId());
    //Add values to subscriber fields
    $subscriberUpdateRemoveRequest->setSubscriberFields(array("FIRST_NAME"=> "Jonathan", "GENDER" => "Male"));
    //Instantiate a gdprFieldConsent object
    $gdprFieldConsent = $subscriberUpdateRemoveRequest->gdprFieldConsentBuilder();
    //Set mobile or email consent
    $gdprFieldConsent->setMobile(false);
    //Create an associative array as property insert the name of gpdr field and as value the gdprFieldConsent object
    $subscriberUpdateRemoveRequest->setGdprFields(array("PROMOTION" => $gdprFieldConsent));
    $subscriberResource->updateSubscriber($subscriberUpdateRemoveRequest);
}





//$lists = getLists($listResource, $listQueryRequest);
//$list = getList($listResource, $listQueryRequest, $lists);
//addAList($listResource, $listRequest);
//querySubscribers($subscriberResource, $querySubscribersBodyRequest, $list);
//updateSubscriber($subscriberResource, $subscriberUpdateRemoveRequest, $list, $subscriber);
//removeList($listResource, $listRequest, $list);
