<?php

	use Apifon\Model\IMAction;
	use Apifon\Model\IMChannel;
	use Apifon\Model\ImRequest;
	use Apifon\Model\LandingProperties;
	use Apifon\Model\MessageContent;
	use Apifon\Model\OtpRequest;
	use Apifon\Model\RemoveRequest;
	use Apifon\Model\request\OAuthConfigurationRequest;
	use Apifon\Model\SmsRequest;
	use Apifon\Model\SubscriberInformation;
	use Apifon\Mookee;
	use Apifon\Resource\BalanceResource;
	use Apifon\Resource\IMResource;
	use Apifon\Resource\OTPResource;
	use Apifon\Resource\SMSResource;

	/**
	 * This is a complete example on how to use the APIFON SDK for PhP.
	 */
	require_once("../Apifon/Model/IRequest.php");
	require_once("../Apifon/Model/SubscribersViewRequest.php");
	require_once("../Apifon/Model/OtpRequest.php");
	require_once("../Apifon/Mookee.php");
	require_once("../Apifon/Security/Hmac.php");
	require_once("../Apifon/Resource/AbstractResource.php");
	require_once("../Apifon/Resource/BalanceResource.php");
	require_once("../Apifon/Resource/IMResource.php");
	require_once("../Apifon/Resource/SMSResource.php");
	require_once("../Apifon/Resource/OTPResource.php");
	require_once("../Apifon/Response/BalanceResponse.php");
	require_once("../Apifon/Response/GatewayResponse.php");
	require_once("../Apifon/Response/OtpResponse.php");
	require_once("../Apifon/Response/OtpVerifyResponse.php");
	require_once("../Apifon/Model/IMAction.php");
	require_once("../Apifon/Model/IMChannel.php");
	require_once("../Apifon/Model/ImRequest.php");
	require_once("../Apifon/Model/LandingProperties.php");
	require_once("../Apifon/Model/MessageContent.php");
	require_once("../Apifon/Model/RemoveRequest.php");
	require_once("../Apifon/Model/Request/OAuthConfigurationRequest.php");
	require_once("../Apifon/Model/SmsRequest.php");
	require_once("../Apifon/Model/SubscriberInformation.php");

	/**
	 * First things first, we need to set our credentials that we got from
	 * the Mookee platform.
	 */

	/**
	 * HMAC
	 */
	Mookee::addCredentials("sms", "Your_SMS_Token", "Your_SMS_Secret_Key");
	Mookee::addCredentials("viber","Your_Viber_Token", "Your_Viber_Secret_Key");
	Mookee::addCredentials("otp", "Your_OTP_Token", "Your_OTP_Secret_Key");

	/**
	 * OAuth2
	 */

	//give any identifier name for the given OAuth configuration
//	$oauth_identifier = "Type an identifier name";

	//fill in your clientId/clientSecret from the mookee platform
//	$oauth_configuration = new OAuthConfigurationRequest("Type your clientId", "Type your clientSecret");

	//setStaging flag, if true requests will be made to the staging environment, false (default) is for production.
//	Mookee::setStaging(false);

	//set OAuth identifier along with the OAuth configuration object
//	Mookee::add_OAuth_resource_and_get_token($oauth_identifier, $oauth_configuration);

	//set the Mookee object to OAuth mode
//	Mookee::set_mookee_to_oauth_mode($oauth_identifier, true);

	//set active identifier to make an api call
//	Mookee::getActive_oauth_token_to_make_an_API_call($oauth_identifier);

	//remove oAuth resource for given identifier
//	Mookee::remove_OAuth_resource($oauth_identifier);

	$choice = "1";

	/**
	 * These are our Resources.
	 */
	$smsResource = new SMSResource();
	$imResource = new IMResource();
	$otpResource = new OTPResource();

	/**
	 * These are our Requests.
	 */
	$smsRequest = new SmsRequest();
	$imRequest = new ImRequest();
	$removeRequest = new RemoveRequest();
	$otpRequest = new OtpRequest();

	/**
	 * Here we generate the date that scheduled messages will be sent.
	 */
	date_default_timezone_set('Europe/Athens');
	$dateTime = new \DateTime();
	try {
		$dateTime->add(new DateInterval('PT1H'));
	} catch (Exception $e) {
	}
	$dateTime->setTimezone(new \DateTimeZone('GMT'));
	$dateTime = $dateTime->format('Y-m-d\TH:i:s');

	/**
	 * Here we create our subscribers.
	 */
	$names = ["John", "Jim", "Alex", "Helen"];
	$names2 = ["Kate", "Julie", "Paul", "Mary"];
	$nums = ["306999999999"/*, "306999999998", "306999999997"*/];

	/**
	 * Here we define the content of our Request.
	 */
	$subscribers = array();
	$imChannel = new IMChannel();
	$imAction = new IMAction();
	$message = new MessageContent();
	$callbackUrl = "http://yourserver/apifon-sdk-php/CallbackHandling/callback.php";
//$callbackUrl = "https://yourserver/callback";
	/**
	 * callback.php listens to callback responses and stores them in a text file.
	 * Callbacks are also displayed on the callback text box of WebServer.php
	 */
	$replyUrl = "https://yourserver/replyurl";

	$choice = $_POST['id'];
	$occasion = $_POST['occasion'];

	/**
	 * Every request has the same structure:
	 *  *First we set the Credential we want to use.
	 *  *Then we build the components of the Request.
	 *  *Finally we build the Request and send it.
	 *  *We print the response we get in console.
	 */
	switch ($choice) {

		/**
		 * This is a simple SMS Request.
		 */
		case "1":
			Mookee::setActiveCredential("sms");

			$smsRequest = new SmsRequest();

			$message = new MessageContent();
			$message->setText("Hello there!");
			$message->setSenderId("Apifon");

			$smsRequest->setStrSubscribers($nums);
			$smsRequest->setMessage($message);
			$smsRequest->setCallbackUrl($callbackUrl);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/sms/send" . "\xA";
				echo "------ SMS Request Body ------" . "\xA";
				printJson($smsRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $smsResource->send($smsRequest);
				printJson($response);
			}
			break;

		/**
		 * In this SMS example we are taking advantage of every property that
		 * can be changed in a Request.
		 */
		case "2":
			Mookee::setActiveCredential("sms");

			$smsRequest = new SmsRequest();

			$message = new MessageContent();
			$message->setText("Hello {name}! Would you like to renew your subscription?");
			$message->setDc(0);
			$message->setSenderId("Apifon");

			$subscribers = array();
			for ($i = 0; $i < sizeof($nums); $i++) {
				$sub = new SubscriberInformation();
				$sub->setNumber($nums[$i]);
				$sub->setCustomId("222");
				$sub->addParams("name", $names[$i]);
				$subscribers[] = $sub;
			}

			$smsRequest->setSubscribers($subscribers);
			$smsRequest->setReferenceId("reference");
			$smsRequest->setMessage($message);
			$smsRequest->setCallbackUrl($callbackUrl);
			$smsRequest->setTte("86400");

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/sms/send" . "\xA";
				echo "------ SMS Request Body ------" . "\xA";
				printJson($smsRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $smsResource->send($smsRequest);
				printJson($response);
			}
			break;

		/**
		 * Here we send a scheduled SMS Request.
		 */
		case "3":
			Mookee::setActiveCredential("sms");

			$smsRequest = new SmsRequest();

			$message = new MessageContent();
			$message->setText("Hello there!");
			$message->setSenderId("Apifon");

			$smsRequest->setStrSubscribers($nums);
			$smsRequest->setMessage($message);
			$smsRequest->setCallbackUrl($callbackUrl);
			$smsRequest->setDate($dateTime);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/sms/send" . "\xA";
				echo "------ SMS Request Body ------" . "\xA";
				printJson($smsRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $smsResource->send($smsRequest);
				printJson($response);
				echo "***";
				echo $response->request_id;
			}
			break;

		/**
		 * This is an SMS Deletion case.
		 */
		case "4":
			Mookee::setActiveCredential("sms");

			$removeRequest = new RemoveRequest();
			$removeRequest->setField("REQUEST_ID");
			$removeRequest->setId($_POST['req']);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/sms/remove" . "\xA";
				echo "------ SMS Remove Request Body ------" . "\xA";
				printJson($removeRequest);
			} else {
				$delResp = $smsResource->remove($removeRequest);
				echo "------ SMS Remove Request Response ------\n" . $delResp . "\xA";
			}
			break;

		/**
		 * In this example we are sending an SMS Request with a landing page.
		 * {apifon_lp} will later be replaced with the URL property of the
		 * landing page.
		 */
		case "5":
			Mookee::setActiveCredential("sms");

			$smsRequest = new SmsRequest();

			$message = new MessageContent();
			$message->setText("Hello {name}! {apifon_lp}");
			$message->setDc(0);
			$message->setSenderId("Apifon");

			$subscribers = array();
			for ($i = 0; $i < sizeof($nums); $i++) {
				$lp = new LandingProperties();
				$lp->setUrl("https://mookee.apifon.com/user/login/");
				$lp->addData("name", $names2[$i]);
				$lp->setRedirect(true);

				$sub = new SubscriberInformation();
				$sub->setNumber($nums[$i]);
				$sub->setCustomId("222");
				$sub->addParams("name", $names[$i]);
				$sub->setLandingPage($lp);
				$subscribers[] = $sub;
			}

			$smsRequest->setSubscribers($subscribers);
			$smsRequest->setReferenceId("reference");
			$smsRequest->setMessage($message);
			$smsRequest->setCallbackUrl($callbackUrl);
			$smsRequest->setTte("86400");

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/sms/send" . "\xA";
				echo "------ SMS Request Body ------" . "\xA";
				printJson($smsRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $smsResource->send($smsRequest);
				printJson($response);
			}
			break;

		/**
		 * Viber Case 1: Send IM that contains only a text.
		 */
		case "6":
			Mookee::setActiveCredential("viber");

			$imRequest = new ImRequest();
			$imChannel = new IMChannel();

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->setSenderId("Mookee");

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * Viber Case 2: Send IM that contains only an image.
		 */
		case "7":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imChannel->setSenderId("Mookee");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * Viber Case 3: Send IM that contains text and action button.
		 */
		case "8":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->setSenderId("Mookee");

			$imChannel->addAction($imAction);

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * Viber Case 4: Send IM that contains text, image and action button.
		 */
		case "9":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->setSenderId("Mookee");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * Complete Viber example.
		 */
		case "10":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setId("channelID");
			$imChannel->setSenderId("Mookee");
			$imChannel->setText("{name}! 50% discount on our membership fee if you renew your subscription today!");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);
			$imChannel->setTtl(86400);
			$imChannel->setExpiryText("Message Expired!!");

			$subscribers = array();
			for ($i = 0; $i < sizeof($nums); $i++) {
				$sub = new SubscriberInformation();
				$sub->setNumber($nums[$i]);
				$sub->setCustomId("222");
				$sub->addParams("name", $names[$i]);
				$subscribers[] = $sub;
			}

			$imRequest->setSubscribers($subscribers);
			$imRequest->setReference("reference");
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * Here we send a scheduled IM Request.
		 */
		case "11":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->setSenderId("Mookee");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);
			$imRequest->setDate($dateTime);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
				echo "***";
				echo $response->request_id;
			}
			break;

		/**
		 * This is an IM Deletion case.
		 */
		case "12":
			Mookee::setActiveCredential("viber");

			$removeRequest = new RemoveRequest();
			$removeRequest->setField("REQUEST_ID");
			$removeRequest->setId($_POST['req']);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/remove" . "\xA";
				echo "------ IM Remove Request Body ------" . "\xA";
				printJson($removeRequest);
			} else {
				$delResp = $imResource->remove($removeRequest);
				echo "------ IM Remove Request Response ------\n" . $delResp . "\xA";
			}
			break;

		/**
		 * In this example we send a Viber message containing a landing page.
		 */
		case "13":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("{apifon_lp}");

			$imChannel->setSenderId("Mookee");
			$imChannel->setText("{name}! 50% discount on our membership fee if you renew your subscription today!");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$subscribers = array();
			for ($i = 0; $i < sizeof($nums); $i++) {
				$lp = new LandingProperties();
				$lp->setUrl("https://mookee.apifon.com/user/login/");
				$lp->addData("name", $names2[$i]);
				$lp->setRedirect(true);

				$sub = new SubscriberInformation();
				$sub->setNumber($nums[$i]);
				$sub->setCustomId("222");
				$sub->addParams("name", $names[$i]);
				$sub->setLandingPage($lp);
				$subscribers[] = $sub;
			}

			$imRequest->setSubscribers($subscribers);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * In this example we send a Viber message with a fallback SMS, in
		 * case Viber delivery fails.
		 */
		case "14":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->setSenderId("Mookee");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$message = new MessageContent();
			$message->setText("Hello there!");
			$message->setSenderId("Apifon");

			$imRequest->setStrSubscribers($nums);
			$imRequest->setMessage($message);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * In this example we send a Viber message with a landing page
		 * fallback SMS, in case Viber delivery fails.
		 */
		case "15":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setSenderId("Mookee");
			$imChannel->setText("50% discount on our membership fee if you renew your subscription today!");
			$imChannel->addImage("http://www.apifon.com/assets/img/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$subscribers = array();
			for ($i = 0; $i < sizeof($nums); $i++) {
				$lp = new LandingProperties();
				$lp->setUrl("https://mookee.apifon.com/user/login/");
				$lp->addData("name", $names2[$i]);
				$lp->setRedirect(true);

				$sub = new SubscriberInformation();
				$sub->setNumber($nums[$i]);
				$sub->setCustomId("222");
				$sub->addParams("name", $names[$i]);
				$sub->setLandingPage($lp);
				$subscribers[] = $sub;
			}

			$message = new MessageContent();
			$message->setText("Hello {name}! {apifon_lp}");
			$message->setSenderId("Apifon");

			$imRequest->setSubscribers($subscribers);
			$imRequest->setMessage($message);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * This is a 2-way Viber example. Any replies sent by the
		 * message recipient will generate a reply-message callback
		 * on the replyURL. Note that this request would require use of
		 * a Viber Sender ID with 2-way messaging enabled. 2-way
		 * messaging can be enabled on a Sender ID via our platform.
		 */
		case "16":
			Mookee::setActiveCredential("viber");

			$imChannel = new IMChannel();
			$imRequest = new ImRequest();

			$imAction = new IMAction();
			$imAction->setTitle("Renew now!");
			$imAction->setTargetUrl("https://www.apifon.com");

			$imChannel->setText("50% discount on our membership fee if you renew your subscription today! Would you like to renew your subscription?");
			$imChannel->setSenderId("Mookee");
			$imChannel->addImage("http://assets.apifon.com/images/boy_girl.jpg");
			$imChannel->addAction($imAction);

			$imRequest->setStrSubscribers($nums);
			$imRequest->setCallbackUrl($callbackUrl);
			$imRequest->setReplyUrl($replyUrl);
			$imRequest->addImChannel($imChannel);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/im/send" . "\xA";
				echo "------ IM Request Body ------" . "\xA";
				printJson($imRequest);
			} else {
				echo "------ Gateway Response Body ------" . "\xA";
				$response = $imResource->send($imRequest);
				printJson($response);
			}
			break;

		/**
		 * This is a Balance Request example in which we are informed about our
		 * remaining Balance and our Plafon.
		 */
		case "17":
			Mookee::setActiveCredential("sms");
			$balanceResource = new BalanceResource();

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/balance" . "\xa";
				echo "------ Balance Request Body ------\nEmpty Body" . "\xA";
			} else {
				echo "------ Balance Response Body ------" . "\xA";
				$response = $balanceResource->send();
				printJson($response);
			}
			break;

		/**
		 * This is a basic OTP Create Request example. We are only setting a phone
		 * number and a reference_id. Reference_id is important because it links to
		 * the generated OTP.
		 */
		case "18":
			Mookee::setActiveCredential("otp");

			$otpRequest = new OtpRequest();

			$otpRequest->setReferenceId($_POST['reference']);
			$otpRequest->setSubscriber($nums[0]);
			$otpRequest->setCallbackUrl($callbackUrl);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/otp/create" . "\xA";
				echo "------ OTP Create Request Body ------" . "\xA";
				printJson($otpRequest);
			} else {
				echo "------ OTP Create Response Body ------" . "\xA";
				$otpResp = $otpResource->create($otpRequest);
				printJson($otpResp);
			}
			break;

		/**
		 * This is a complete OTP Create Request example. We are specifying every
		 * field of the request to our preferences.
		 */
		case "19":
			Mookee::setActiveCredential("otp");

			$otpRequest = new OtpRequest();

			$msgContent = new MessageContent();
			$msgContent->setText("Hello There! Here is your OTP: {apifon_otp}");
			$msgContent->setSenderId("Apifon");

			$otpRequest->setReferenceId($_POST['reference']);;
			$otpRequest->setSubscriber($nums[0]);
			$otpRequest->setCodeLength(6);
			$otpRequest->setCodeType("numeric");
			$otpRequest->setCallbackUrl($callbackUrl);
			$otpRequest->setExpire(300);
			$otpRequest->setMessage($msgContent);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/otp/create" . "\xA";
				echo "------ OTP Create Response Body ------" . "\xA";
				printJson($otpRequest);
			} else {
				echo "------ OTP Create Response Body ------" . "\xA";
				$otpResp = $otpResource->create($otpRequest);
				printJson($otpResp);
			}
			break;

		/**
		 * This is an OTP Verification Request example. When a subscriber is using
		 * the OTP that we generated for him, we want to verify that the OTP is valid.
		 * We are using the reference_id that we used to generate the OTP and the OTP that
		 * we are provided to make this verification.
		 */
		case "20":
			Mookee::setActiveCredential("otp");

			$otpReference = trim($_POST['reference']);
			$otpCode = trim($_POST['otp']);

			if ($occasion == "0") {
				echo "Sending Request to Endpoint: /services/otp/verify/" . $otpReference . "/" . $otpCode . "\xA";
				echo "------ OTP Verify Request Body ------\nEmpty Body" . "\xA";
			} else {
				echo "------ OTP Verify Response Body ------" . "\xA";
				$otpVerResp = $otpResource->verify($otpReference, $otpCode);
				printJson($otpVerResp);
			}
			break;
	}

	function printJson($json)
	{
		$res = preg_replace('/,\s*"[^"]+":null|"[^"]+":null,?/', '', json_encode(get_object_vars($json)));
		$res = json_decode($res);
		echo json_encode($res, JSON_PRETTY_PRINT) . "\xA";
	}

